#
# spec file for package ocaml-luv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with ocaml_luv_testsuite
%define build_flavor %nil
%if "%build_flavor" == "testsuite"
%if %{without ocaml_luv_testsuite}
ExclusiveArch:  do-not-build
%endif
%define nsuffix -testsuite
%else
%define nsuffix %nil
%endif

%define     pkg ocaml-luv
Name:           %pkg%nsuffix
Version:        0.5.13
Release:        1.1
%{?ocaml_preserve_bytecode}
Summary:        Binding to libuv cross-platform asynchronous I/O
License:        MIT
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/luv
Source0:        %pkg-%version.tar.xz
Patch0:         %pkg.patch
BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-rpm-macros >= 20240909
BuildRequires:  ocamlfind(ctypes)
BuildRequires:  pkgconfig(libuv)

%if "%build_flavor" == "testsuite"
BuildRequires:  ocamlfind(alcotest)
BuildRequires:  ocamlfind(luv)
%endif

%description
Luv is a binding to libuv, the cross-platform C library that does
asynchronous I/O in Node.js and runs its main loop.

Besides asynchronous I/O, libuv also supports multiprocessing and
multithreading. Multiple event loops can be run in different threads. libuv also
exposes a lot of other functionality, amounting to a full OS API, and an
alternative to the standard module Unix.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version
Requires:       pkgconfig(libuv)

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.

%prep
%autosetup -p1 -n %pkg-%version

%build
export LUV_USE_SYSTEM_LIBUV=yes
dune_release_pkgs='luv,luv_unix'
%ocaml_dune_setup
%if "%build_flavor" == ""
%ocaml_dune_build
%endif

%install
%if "%build_flavor" == ""
export LUV_USE_SYSTEM_LIBUV=yes
%ocaml_dune_install
%ocaml_create_file_list
%endif

%if "%build_flavor" == "testsuite"
%check
%if %{without ocaml_luv_testsuite}
exit 0
%endif
export LUV_USE_SYSTEM_LIBUV=yes
OCAML_DUNE_RUNTEST_ARGS='--no-buffer -j1'
%ocaml_dune_test
%endif

%if "%build_flavor" == ""
%files -f %name.files

%files devel -f %name.files.devel

%endif

%changelog
* Sun May 11 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.5.13
  * Breaking
    + Luv.Resource.free_memory and Luv.Resource.total_memory now return
    options, in accordance with a clarification in libuv (#153).
    + Filename in callback of Luv.FS_event.start can be None, in accordance
    with a clarification in libuv (#155).
    + Rename fields of Luv.Time.timeval (dbd4e43).
  * Additions
    + Upgrade libuv to 1.48.0, including 1.47.0, 1.46.0, 1.45.0 and io_uring
    support (#153, #154, #155, #158).
    + Expose uv_cpumask_size as Luv.System_info.cpumask_size,
    uv_thread_setaffinity as Luv.Thread.setaffinity, uv_thread_getaffinity as
    Luv.Thread.getaffinity (#153).
    + Expose UV_ENODATA as  `ENODATA (#153).
    + Expose uv_metrics_info as Luv.Metrics.info (#153).
    + Expose uv_thread_getcpu as Luv.Thread.getcpu (#153).
    + Expose uv_get_available_memory as Luv.Resource.available_memory (#153).
    + Expose uv_os_get_passwd2 as ?uid parameter of Luv.Passwd.get_passwd (#153).
    + Expose uv_os_get_group as Luv.Passwd.get_group (#153).
    + Expose uv_clock_gettime as Luv.Time.clock_gettime (#153).
    + Expose uv_pipe_bind2 and uv_pipe_connect2 as ?no_truncate parameters of
    Luv.Pipe.bind and Luv.Pipe.connect (#154).
    + Expose EUNATCH as  `EUNATCH (#154).
    + Expose UTF-16/WTF-8 conversion functions in new module Luv.String (#155).
    + Expose uv_thread_setpriority as Luv.Thread.setpriority and
    uv_thread_getpriority as Luv.Thread.getpriority (#158).
    + Expose UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME as
    ?windows_file_path_exact_name parameter of Luv.Process.spawn (#158).
- Refresh ocaml-luv.patch
* Mon Mar  3 2025 ohering@suse.de
- Handle strict API in newer OCaml versions
* Tue May  2 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 0.5.12
  no changelog provided
* Mon Apr  4 2022 ohering@suse.de
- Update to version 0.5.11
  no changelog provided
* Sat Sep 11 2021 ohering@suse.de
- Update to version 0.5.10
  no changelog provided
* Sun May  9 2021 ohering@suse.de
- Update to version 0.5.8
  no changelog provided
* Fri Apr  9 2021 ohering@suse.de
- Initial version 0.5.7
